@@ -1,10 +1,12 @@
-clusterMapLB = function (cl, fun, ..., MoreArgs = NULL) {
+clusterMapLB = function(cl, fun, ..., MoreArgs = NULL) {
+
   force(fun)
   args = list(...)
   force(MoreArgs)
 
-  if (length(args) == 0L)
+  if (length(args) == 0L) {
     stop("need at least one argument")
+  }
   n = viapply(args, length)
   vlen = max(n)
   ind = which(n != vlen)
